@@ -145,6 +145,7 @@ static const char rcsid[] = "$Id: photoproc.c,v 1.33 2010/04/23 12:19:35 gerlof
 #include <string.h>
 #include <unistd.h>
 #include <ctype.h>
+#include <time.h>
 
 #include "atop.h"
 #include "photoproc.h"
@@ -165,6 +166,7 @@ static int	procstat(struct tstat *, unsigned long long, char);
 static int	procstatus(struct tstat *);
 static int	procio(struct tstat *);
 static void	proccmd(struct tstat *);
+static void	procsmaps(struct tstat *);
 
 int
 photoproc(struct tstat *tasklist, int maxtask)
@@ -248,25 +250,33 @@ photoproc(struct tstat *tasklist, int maxtask)
 		*/
 		curtask	= tasklist+tval;
 
-		if ( !procstat(curtask, bootepoch, 1)) /* from /proc/pid/stat */
+		if ( !procstat(curtask, bootepoch, 1))	/* from /proc/pid/stat */
 		{
 			if ( chdir("..") == -1);
 			continue;
 		}
 
-		if ( !procstatus(curtask) )	    /* from /proc/pid/status  */
+		if ( !procstatus(curtask) )		/* from /proc/pid/status  */
 		{
 			if ( chdir("..") == -1);
 			continue;
 		}
 
-		if ( !procio(curtask) )		    /* from /proc/pid/io      */
+		if ( !procio(curtask) )			/* from /proc/pid/io      */
 		{
 			if ( chdir("..") == -1);
 			continue;
 		}
 
-		proccmd(curtask);		    /* from /proc/pid/cmdline */
+		proccmd(curtask);			/* from /proc/pid/cmdline */
+
+		/*
+		** reading the smaps file for every process with every sample
+		** is a really 'expensive' from a CPU consumption point-of-view,
+		** so gathering this info is optional
+		*/
+		if (calcpss)
+			procsmaps(curtask);		/* from /proc/pid/smaps */
 
 		// read network stats from netatop
 		netatop_gettask(curtask->gen.tgid, 'g', curtask);
@@ -406,27 +416,44 @@ procstat(struct tstat *curtask, unsigned long long bootepoch, char isproc)
 {
 	FILE	*fp;
 	int	nr;
-	char	line[4096], *cmdhead, *cmdtail;
+	char	line[4096], *p, *cmdhead, *cmdtail;
 
 	if ( (fp = fopen("stat", "r")) == NULL)
 		return 0;
 
-	if (fgets(line, sizeof line, fp) == NULL)
+	if ( (nr = fread(line, 1, sizeof line-1, fp)) == 0)
 	{
 		fclose(fp);
 		return 0;
 	}
 
+	line[nr] = '\0';	// terminate string
+
 	/*
     	** fetch command name
 	*/
 	cmdhead = strchr (line, '(');
 	cmdtail = strrchr(line, ')');
+
+	if (!cmdhead || !cmdtail || cmdtail < cmdhead) // parsing failed?
+	{
+		fclose(fp);
+		return 0;
+	}
+
 	if ( (nr = cmdtail-cmdhead-1) > PNAMLEN)
 		nr = PNAMLEN;
 
-	memcpy(curtask->gen.name, cmdhead+1, nr);
-	*(curtask->gen.name+nr) = 0;
+	p = curtask->gen.name;
+
+	memcpy(p, cmdhead+1, nr);
+	*(p+nr) = 0;
+
+	while ( (p = strchr(p, '\n')) != NULL)
+	{
+		*p = '?';
+		p++;
+	}
 
 	/*
   	** fetch other values
@@ -534,6 +561,18 @@ procstatus(struct tstat *curtask)
 			continue;
 		}
 
+		if (memcmp(line, "envID:", 6) ==0)
+		{
+			sscanf(line, "envID: %d", &(curtask->gen.ctid));
+			continue;
+		}
+
+		if (memcmp(line, "VPid:", 5) ==0)
+		{
+			sscanf(line, "VPid: %d", &(curtask->gen.vpid));
+			continue;
+		}
+
 		if (memcmp(line, "Threads:", 8)==0)
 		{
 			sscanf(line, "Threads: %d", &(curtask->gen.nthr));
@@ -677,3 +716,50 @@ proccmd(struct tstat *curtask)
 		}
 	}
 }
+
+/*
+** open file "smaps" and obtain required info
+*/
+static void
+procsmaps(struct tstat *curtask)
+{
+	FILE	*fp;
+	char	line[4096];
+	count_t	pssval;
+
+
+	/*
+ 	** open the file (always succeeds, even if no root privs)
+	*/
+	regainrootprivs();
+
+	if ( (fp = fopen("smaps", "r")) )
+	{
+		curtask->mem.pmem = 0;
+
+		while (fgets(line, sizeof line, fp))
+		{
+			if (memcmp(line, "Pss:", 4) != 0)
+				continue;
+
+			// PSS line found to be accumulated
+			sscanf(line, "Pss: %llu", &pssval);
+			curtask->mem.pmem += pssval;
+		}
+
+		/*
+		** verify if fgets returned NULL due to error i.s.o. EOF
+		*/
+		if (ferror(fp))
+			curtask->mem.pmem = (unsigned long long)-1LL;
+
+		fclose(fp);
+	}
+	else
+	{
+		curtask->mem.pmem = (unsigned long long)-1LL;
+	}
+
+	if (! droprootprivs())
+		cleanstop(42);
+}
