@@ -23,6 +23,7 @@
 */
 #define USERSTUB	9999999
 #define MAXUSERSEL	64
+#define MAXPID		32
 
 struct syscap {
 	int	nrcpu;
@@ -36,9 +37,15 @@ struct pselection {
 	char	username[256];
 	uid_t	userid[MAXUSERSEL];
 
+	pid_t	pid[MAXPID];
+
 	char	progname[64];
 	int	prognamesz;
 	regex_t	progregex;
+
+	char	argname[64];
+	int	argnamesz;
+	regex_t	argregex;
 };
 
 struct sselection {
@@ -58,9 +65,9 @@ struct sselection {
 /*
 ** color names
 */
-#define	COLORLOW	2
-#define	COLORMED	3
-#define	COLORHIGH	4
+#define	COLORINFO	2
+#define	COLORALMOST	3
+#define	COLORCRIT	4
 #define	COLORTHR	5
 
 /*
@@ -85,6 +92,8 @@ struct sselection {
 #define	MSORTAUTO	'A'
 
 #define	MTHREAD		'y'
+#define	MCALCPSS	'R'
+#define	MSUPEXITS	'G'
 #define	MCOLORS		'x'
 #define	MSYSFIXED	'f'
 #define	MSYSNOSORT	'F'
@@ -92,6 +101,8 @@ struct sselection {
 
 #define	MSELUSER	'U'
 #define	MSELPROC	'P'
+#define	MSELPID		'I'
+#define	MSELARG		'/'
 #define	MSELSYS		'S'
 
 #define	MALLPROC	'a'
@@ -129,7 +140,7 @@ void	showcmdproc(struct tstat *, double, int, int);
 
 void	printg     (const char *, ...);
 int	prisyst(struct sstat  *, int, int, int, int, struct sselection *,
-			char *, int, int, int, int, int);
+			char *, int, int, int, int, int, int, int);
 int	priproc(struct tstat  **, int, int, int, int, int, char, char,
 	        struct syscap *, int, int);
 void	priphead(int, int, char *, char *, char);
