@@ -274,7 +274,6 @@ static const char rcsid[] = "$Id: showlinux.c,v 1.70 2010/10/23 14:04:12 gerlof
 #include <string.h>
 #include <errno.h>
 #include <fcntl.h>
-#include <termio.h>
 #include <unistd.h>
 #include <stdarg.h>
 #include <curses.h>
@@ -484,9 +483,9 @@ sys_printdef *netnetsyspdefs[] = {
 };
 sys_printdef *netintfsyspdefs[] = {
 	&syspdef_NETNAME,
-	&syspdef_NETSPEEDMAX,
 	&syspdef_NETPCKI,
 	&syspdef_NETPCKO,
+	&syspdef_NETSPEEDMAX,
 	&syspdef_NETSPEEDIN,
 	&syspdef_NETSPEEDOUT,
 	&syspdef_NETCOLLIS,
@@ -564,8 +563,8 @@ proc_printdef *allprocpdefs[]=
 	&procprt_UDPSASZ,
 	&procprt_RNET,
 	&procprt_SNET,
-	&procprt_RNETBW,
-	&procprt_SNETBW,
+	&procprt_BANDWI,
+	&procprt_BANDWO,
 	&procprt_SORTITEM,
         0
 };
@@ -1055,11 +1054,11 @@ pricumproc(struct sstat *sstat, struct tstat **proclist,
                 {
                     make_sys_prints(netinterfaceline, MAXITEMS,
 	                "NETNAME:8 "
-	                "NETSPEEDMAX:5 "
 	                "BLANKBOX:0 "
 	                "NETPCKI:7 "
 	                "NETPCKO:7 "
 	                "BLANKBOX:0 "
+	                "NETSPEEDMAX:5 "
 	                "NETSPEEDIN:6 "
 	                "NETSPEEDOUT:6 "
 	                "BLANKBOX:0 "
@@ -1138,7 +1137,7 @@ priphead(int curlist, int totlist, char *showtype, char *showorder,
                         "PID:10 TID:6 "
 			"TCPRCV:9 TCPRASZ:4 TCPSND:9 TCPSASZ:4 "
 			"UDPRCV:8 UDPRASZ:3 UDPSND:8 UDPSASZ:3 "
-			"RNETBW:10 SNETBW:10 "
+			"BANDWI:10 BANDWO:10 "
                         "SORTITEM:10 CMD:10", 
                         "built-in netprocs");
 
