@@ -331,8 +331,8 @@ extern proc_printdef procprt_UDPSND;
 extern proc_printdef procprt_UDPSASZ;
 extern proc_printdef procprt_RNET;
 extern proc_printdef procprt_SNET;
-extern proc_printdef procprt_RNETBW;
-extern proc_printdef procprt_SNETBW;
+extern proc_printdef procprt_BANDWI;
+extern proc_printdef procprt_BANDWO;
 extern proc_printdef procprt_SORTITEM;
 
 
